==> jruby-complete-1.6.8-sources.jar: org/jruby/ast/RestArgNode.java <==
/*
 ***** BEGIN LICENSE BLOCK *****
 * Version: CPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Common Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/cpl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2008 Thomas E Enebo <enebo@acm.org>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the CPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the CPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.ast;

import org.jruby.ast.types.INameNode;
import org.jruby.ast.visitor.NodeVisitor;
import org.jruby.lexer.yacc.ISourcePosition;

/*
 * The rest argument for a method (def foo(a, *b, c)).
 */
public class RestArgNode extends ArgumentNode implements INameNode {
    public RestArgNode(ISourcePosition position, String name, int index) {
        super(position, name, index);
    }

    // 1.9 only - lvar assign logic returns an Argument node
    public RestArgNode(ArgumentNode argNode) {
        this(argNode.getPosition(), argNode.getName(), argNode.getIndex());
    }

    @Override
    public NodeType getNodeType() {
        return NodeType.RESTARG;
    }

    @Override
    public Object accept(NodeVisitor iVisitor) {
        return iVisitor.visitRestArgNode(this);
    }
}

==> jruby-complete-9.2.17.0-sources.jar: org/jruby/ast/RestArgNode.java <==
/*
 ***** BEGIN LICENSE BLOCK *****
 * Version: EPL 2.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Eclipse Public
 * License Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/epl-v20.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2008 Thomas E Enebo <enebo@acm.org>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the EPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the EPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/

package org.jruby.ast;

import org.jruby.RubySymbol;
import org.jruby.ast.types.INameNode;
import org.jruby.ast.visitor.NodeVisitor;
import org.jruby.lexer.yacc.ISourcePosition;

/*
 * The rest argument for a method (def foo(a, *b, c)).
 */
public class RestArgNode extends ArgumentNode implements INameNode {
    public RestArgNode(ISourcePosition position, RubySymbol name, int index) {
        super(position, name, index);
    }

    // 1.9 only - lvar assign logic returns an Argument node
    public RestArgNode(ArgumentNode argNode) {
        this(argNode.getPosition(), argNode.getName(), argNode.getIndex());
    }

    public boolean isAnonymous() {
        RubySymbol argName = getName();

        return argName == null || argName.getBytes().realSize() == 0;
    }

    @Override
    public NodeType getNodeType() {
        return NodeType.RESTARG;
    }

    @Override
    public <T> T accept(NodeVisitor<T> iVisitor) {
        return iVisitor.visitRestArgNode(this);
    }
}
